# Vector API

Utilities for manipulating vector data.
Vectors can either be represented as dense (using `array<numeric>`)
or sparse (using `map<any_type, numeric>`)

::: mismo.vector.norm
::: mismo.vector.normalize
::: mismo.vector.dot
::: mismo.vector.cosine_similarity
::: mismo.vector.mul